# Generated by roxygen2: do not edit by hand

export(best_split_free)
export(calc_detector)
export(combine_detectors)
export(decompose_signal_core)
export(detect_cp_ecdf)
export(fit_global_mlp)
export(fit_mlp)
export(ma)
export(plot_mlp_fits_interactive)
export(scan_cp)
export(scan_cp_multi_async)
export(scan_cp_multi_sync)
export(select_best_spike)
export(simulate_piecewise_signal_idx)
import(RSNNS)
import(doSNOW)
import(foreach)
import(parallel)
importFrom(RSNNS,mlp)
importFrom(magrittr,"%>%")
importFrom(plotly,add_lines)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(pracma,findpeaks)
importFrom(stats,ecdf)
importFrom(stats,filter)
importFrom(stats,kmeans)
importFrom(stats,median)
importFrom(stats,rnorm)
importFrom(tidyr,replace_na)
importFrom(utils,modifyList)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
